@@ -50,8 +50,8 @@ class QSpinBox;
 class QStringList;
 class WaitDlg;
 
-class PluginKateInsertCommand : public Kate::Plugin, 
-                                Kate::PluginViewInterface, 
+class PluginKateInsertCommand : public Kate::Plugin,
+                                Kate::PluginViewInterface,
                                 Kate::PluginConfigInterfaceExtension
 {
   Q_OBJECT
@@ -71,10 +71,10 @@ class PluginKateInsertCommand : public Kate::Plugin,
     uint configPages () const { return 1; }
     Kate::PluginConfigPage *configPage (uint , QWidget *w, const char *name=0);
     QString configPageName(uint) const { return i18n("Insert Command"); };
-    QString configPageFullName(uint) const { 
+    QString configPageFullName(uint) const {
       return i18n("Configure Insert Command Plugin"); };
-    QPixmap configPagePixmap (uint /*number = 0*/, 
-                              int /*size = KIcon::SizeSmall*/) const 
+    QPixmap configPagePixmap (uint /*number = 0*/,
+                              int /*size = KIcon::SizeSmall*/) const
                                { return 0L; };
 
   private:
@@ -130,9 +130,9 @@ private slots:
 class WaitDlg : public KDialogBase
 {
   public:
-    WaitDlg(QWidget* parent, 
-            const QString& text=QString::null, 
-            const QString& title=QString(i18n("Please Wait")));
+    WaitDlg(QWidget* parent,
+            const QString& text=QString::null,
+            const QString& title=i18n("Please Wait"));
     ~WaitDlg();
 };
 
