@@ -1,10 +1,9 @@
 /***************************************************************************
-                          playerInterface.cpp
-            this is the abstract class to access any player from
+              this is the abstract class to access a player from
                              -------------------
     begin                : Mon Jan 15 21:09:00 CEST 2001
     copyright            : (C) 2001-2002 by Stefan Gehn
-    email                : sgehn@gmx.net
+    email                : metz {AT} gehn {DOT} net
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,6 +17,18 @@
 
 #include "playerInterface.h"
 #include "playerInterface.moc"
+#include <kapplication.h>
+#include <kmessagebox.h>
+#include <klocale.h>
 
 PlayerInterface::PlayerInterface() { }   // Constructor
 PlayerInterface::~PlayerInterface() { }  // Destructor
+
+void PlayerInterface::startPlayer(const QString &desktopname)
+{
+	if (KApplication::startServiceByDesktopName(desktopname, QStringList(),
+		0, 0, 0, "", false) > 0)
+	{
+		KMessageBox::error(0, i18n("Could not start media player."));
+	}
+}
