@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <sys/utsname.h>
@@ -52,7 +52,7 @@ K_EXPORT_COMPONENT_FACTORY (libuachangerplugin, UAChangerPluginFactory (&aboutda
 
 UAChangerPlugin::UAChangerPlugin( QObject* parent, const char* name,
                                   const QStringList & )
-                :KParts::Plugin( parent, name ), 
+                :KParts::Plugin( parent, name ),
                   m_bSettingsLoaded(false), m_part(0L), m_config(0L)
 {
   setInstance(UAChangerPlugin::instance());
@@ -112,44 +112,46 @@ void UAChangerPlugin::parseDescFiles()
   }
 
   KTrader::OfferList::ConstIterator it = list.begin();
-  for ( ; it != list.end(); ++it )
+  KTrader::OfferList::ConstIterator lastItem = list.end();
+
+  for ( ; it != lastItem; ++it )
   {
     QString tmp = UA_PTOS("X-KDE-UA-FULL");
     QString tag = UA_PTOS("X-KDE-UA-TAG");
-    if(tag != "IE" && tag != "NN" && tag != "MOZ") tag = "OTHER";
+
+    if(tag != "IE" && tag != "NN" && tag != "MOZ")
+      tag = "OTHER";
+
     if ( (*it)->property("X-KDE-UA-DYNAMIC-ENTRY").toBool() )
     {
-      int pos;
-      if ( (pos=tmp.find("appSysName")) != -1 )
-        tmp.replace( pos, 10, QFL1(utsn.sysname) );
-      if ( (pos=tmp.find("appSysRelease")) != -1 )
-        tmp.replace( pos, 13, QFL1(utsn.release) );
-      if ( (pos=tmp.find("appMachineType")) != -1 )
-        tmp.replace( pos, 14, QFL1(utsn.machine) );
-      if ( (pos=tmp.find("appLanguage")) != -1 )
-        tmp.replace( pos, 11, languageList.join(QFL1(", ")) );
-      if ( (pos=tmp.find("appPlatform")) != -1 )
-        tmp.replace( pos, 11, QFL1("X11") );
+      tmp.replace( QFL1("appSysName"), QFL1(utsn.sysname) );
+      tmp.replace( QFL1("appSysRelease"), QFL1(utsn.release) );
+      tmp.replace( QFL1("appMachineType"), QFL1(utsn.machine) );
+      tmp.replace( QFL1("appLanguage"), languageList.join(QFL1(", ")) );
+      tmp.replace( QFL1("appPlatform"), QFL1("X11") );
     }
 
     if ( m_lstIdentity.contains(tmp) )
       continue; // Ignore dups!
 
     m_lstIdentity << tmp;
-    tmp = QString("%1 %2").arg(UA_PTOS("X-KDE-UA-SYSNAME")).arg(UA_PTOS("X-KDE"
-                  "-UA-SYSRELEASE"));
-    if ( tmp.stripWhiteSpace().isEmpty() ) {
+    tmp = QString("%1 %2").arg(UA_PTOS("X-KDE-UA-SYSNAME")).arg(UA_PTOS("X-KDE-UA-SYSRELEASE"));
+
+    if ( tmp.stripWhiteSpace().isEmpty() )
+    {
       if(tag == "NN" || tag == "IE" || tag == "MOZ")
          tmp = i18n("Version %1").arg(UA_PTOS("X-KDE-UA-VERSION"));
       else
          tmp = QString("%1 %2").arg(UA_PTOS("X-KDE-UA-NAME")).arg(UA_PTOS("X-KDE-UA-VERSION"));
     }
-    else {
+    else
+    {
       if(tag == "NN" || tag == "IE" || tag == "MOZ")
          tmp = i18n("Version %1 on %2").arg(UA_PTOS("X-KDE-UA-VERSION")).arg(tmp);
       else
         tmp = i18n("%1 %2 on %3").arg(UA_PTOS("X-KDE-UA-NAME")).arg(UA_PTOS("X-KDE-UA-VERSION")).arg(tmp);
     }
+
     m_lstAlias << tmp;
 
     /* sort in this UA Alias alphabetically */
@@ -163,9 +165,12 @@ void UAChangerPlugin::parseDescFiles()
       }
       ++e;
     }
+
     if ( !tmp.isEmpty() )
       ualist.append( m_lstAlias.count()-1 );
+
     m_mapAlias[tag] = ualist;
+
     if(tag == "OTHER")
        m_mapBrowser[tag] = i18n("Other");
     else
