@@ -41,7 +41,8 @@
 
 extern "C" Plugin *create_plugin()
 {
-	return new Wakeup();
+  KGlobal::locale()->insertCatalogue("wakeup");
+  return new Wakeup();
 }
 
 Wakeup *Wakeup::wakeme = 0;
@@ -199,7 +200,7 @@ WakeupPrefs::WakeupPrefs( QObject *parent ) :
 	hour7->setButtonSymbols(QSpinBox::PlusMinus);
 	minute7 = new KMinuteSpinBox(1, this, "Minute7");
 	
-	QLabel *selectday = new QLabel (i18n("Select days :"),this);
+	QLabel *selectday = new QLabel (i18n("Select days:"),this);
 	QLabel *choosehour = new QLabel (i18n("Hour"),this);
 	QLabel *choosemin = new QLabel (i18n("Minute"),this);
 	grid->addWidget (selectday,0,0,Qt::AlignLeft); 
@@ -239,12 +240,12 @@ WakeupPrefs::WakeupPrefs( QObject *parent ) :
 	QButtonGroup *modeGroup = new QButtonGroup (3, Qt::Vertical, i18n ("Volume Control"),this);
 	alarmmode = new QRadioButton (i18n("No change to volume, just starts the player"),modeGroup);
 	nightmode = new QRadioButton (i18n("The volume decreases slowly and finally stops the player"),modeGroup);
-	morningmode = new QRadioButton (i18n("The player starts and the volume raises up to the chosen value"),modeGroup);
+	morningmode = new QRadioButton (i18n("The player starts and the volume increases to the chosen value"),modeGroup);
 	modeGroup->setExclusive(true);
 	morningmode->setChecked(true);
 
 	volFrame = new QFrame (this);
-	QLabel *volEndLabel = new QLabel (i18n("Volume raises up to :"), volFrame);
+	QLabel *volEndLabel = new QLabel (i18n("Volume increases to:"), volFrame);
 	volEndValue = new KPercentSpinBox (1 ,volFrame,"volendvalue");
 
 	layout->addWidget(modeGroup);
