@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>
- * 
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
@@ -33,7 +33,7 @@
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qframe.h>
-
+#include <kurldrag.h>
 #include <kstatusbar.h>
 #include <kglobal.h>
 #include <kconfig.h>
@@ -116,7 +116,7 @@ Charlatan::Charlatan()
 	buttonLayout->addWidget(stopButton_);
 	buttonLayout->addWidget(restartButton_);
 	buttonLayout->addWidget(playButton_);
-	
+
 	playListToggleButton_	->installEventFilter(this);
 	previousButton_				->installEventFilter(this);
 	nextButton_						->installEventFilter(this);
@@ -237,7 +237,7 @@ void Charlatan::closeEvent(QCloseEvent *)
 
 void Charlatan::dragEnterEvent(QDragEnterEvent *event)
 {
-	event->accept(QUriDrag::canDecode(event));
+	event->accept(KURLDrag::canDecode(event));
 }
 
 void Charlatan::dropEvent(QDropEvent *event)
