@@ -28,7 +28,7 @@ NexPlugin::~NexPlugin()
 
 void NexPlugin::init()
 {
-	process << KStandardDirs::findExe("noatunnex.bin");
+	process << KStandardDirs::findExe("nexscope.bin");
 
 	// Note that process.start() will fail if findExe fails, so there's no real need
 	// for two separate checks.
