@@ -13,7 +13,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include "renderer.h"
@@ -123,8 +123,10 @@ void display_surface(void)
 			{
 				for (j=1; j<scr_par.width; j++)
 				{
-					*(pdest++) = current_colors[*psrc++];
-					*(pdest++) = *(pdest-1);
+					*pdest = current_colors[*psrc++];
+					pdest++;
+					*pdest = *(pdest-1);
+      					pdest++;
 				}
 
 				memcpy(screen->pixels+i*screen->pitch*2+screen->pitch,
